@@ -1,4 +1,3 @@
-from datetime import datetime
 from typing import List, Optional
 from pydantic import BaseModel
 from uuid import UUID
@@ -7,7 +6,7 @@ from uuid import UUID
 
 class ItemModel(BaseModel):
     _id: UUID
-    sequence: int
+    seq: int
     id: UUID
     name: str
     title: str
@@ -16,12 +15,13 @@ class ItemModel(BaseModel):
     path: str
     route: str
     tags: Optional[str]
+    perms: Optional[List[str]]
 
 
 class MenuModel(BaseModel):
     _id: UUID
     node: str
-    sequence: int
+    seq: int
     id: UUID
     name: str
     title: str
