@@ -3,7 +3,7 @@ from pydantic import BaseModel
 from uuid import UUID
 
 
-class AccountModel(BaseModel):
+class ProjectModel(BaseModel):
     id: UUID
     name: str
     title: str
@@ -16,7 +16,7 @@ class AccountModel(BaseModel):
     
 class AppModel(BaseModel):
     id: UUID
-    account: AccountModel
+    project: ProjectModel
     mode: str
     name: str
     title: str
@@ -30,22 +30,9 @@ class AppModel(BaseModel):
     icon_url: str
     icon_light_url: str
     icon_dark_url: str
-    client_id: str
-    client_secret: str
-    redirect_uri: str
-    response_type: str
-    grant_type: str
     domain: str
-    scope: str
-    aes_key: str
-    rsa_public_pem: str
-    rsa_private_pem: str
-    rsa_passphrase: str
-    algorithm: str
-    claims: dict
     tags: str
     colour: str
     is_active: bool
     created_at: datetime
     updated_at: datetime
-
