@@ -2,7 +2,7 @@ from typing import Optional, Union
 from uuid import UUID
 from pydantic import BaseModel
 
-from .app_model import AccountModel
+from .app_model import ProjectModel
 from .location_model import LocationModel
 from .nation_model import NationModel
 from .access_model import NavModel
@@ -12,7 +12,7 @@ from .user_model import UserModel
 
 class ContextModel(BaseModel):
     id: UUID
-    account: AccountModel
+    project: ProjectModel
     mode: str
     name: str
     title: str
