@@ -54,4 +54,4 @@ class UserModel(BaseModel):
     updated_at: datetime
     addreses: Optional[List[AddressModel]]
     role: Optional[RoleModel]
-    permissions: Optional[List[str]]
+    perms: Optional[List[str]]
